@@ -1,7 +1,5 @@
-#!/usr/bin/python
-
 import requests
-
+import json
 
 class Refund:
 
@@ -10,7 +8,7 @@ class Refund:
 
     def process(self, order_id=None, amount=None):
         response = requests.post(self.gateway.config.get_api_url() + "/payment/" + str(order_id) + "/refund",
-                                 data={"amount": amount},
+                                 data=json.dumps({"amount": amount}),
                                  headers={"X-ApiKey": self.gateway.config.get_private_key()})
 
-        return response.json()
+        return response
